@@ -248,6 +248,10 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
 
         :rtype: generator
         """
+        from django.conf import settings
+        # Значение PAGE_LIMIT по умолчанию 1. С большим PAGE_LIMIT можно заддосить ГАР
+        page_limit = settings.GAR.get('PAGE_LIMIT', 1)
+
         if page is None:
             pages = count(start=1)
         else:
@@ -263,7 +267,7 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
                     if self._filter(object_data):
                         yield object_data
 
-                if not drf_data['next']:
+                if not drf_data['next'] or page_number >= page_limit:
                     break
             else:
                 break
@@ -369,9 +373,6 @@ class AddressObjectLoaderBase(ParentFilterMixin, LoaderBase):
         if self._levels:
             result['level'] = ','.join(map(str, self._levels))
 
-        if self._typenames:
-            result['typename'] = ','.join(map(str, self._typenames))
-
         return result
 
     def _filter(self, object_data):
@@ -404,6 +405,14 @@ class AddressObjectLoader(AddressObjectLoaderBase):
         self._levels = levels
         self._typenames = typenames
 
+    def _get_params(self):
+        result = super(AddressObjectLoader, self)._get_params()
+
+        if self._typenames:
+            result['typename'] = ','.join(map(str, self._typenames))
+
+        return result
+
 
 class PlaceLoader(AddressObjectLoaderBase):
     """
