@@ -119,7 +119,7 @@ def find_house(house_number='', parent_id=None, timeout=None):
     return config.backend.find_house(house_number, parent_id, timeout)
 
 
-def get_house(house_id, parent_id=None, timeout=None):
+def get_house(house_id, timeout=None):
     """Возвращает информацию о здании по его ID в ГАР.
 
     .. important::
@@ -129,15 +129,13 @@ def get_house(house_id, parent_id=None, timeout=None):
        идентификаторы.
 
     :param house_id: ID здания.
-    :param parent_id: ID адресного объекта, в котором находится здание.
-        Необходимость указывать ID определяется используемым бэкендом.
     :param float timeout: Timeout запросов к серверу ГАР в секундах.
 
     :rtype: m3_gar_client.data.House
     """
     from m3_gar_client import config
 
-    return config.backend.get_house(house_id, parent_id, timeout)
+    return config.backend.get_house(house_id, timeout)
 
 
 def get_address_object_name(address_object):
